# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from powergate.user.v1 import user_pb2 as powergate_dot_user_dot_v1_dot_user__pb2


class UserServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BuildInfo = channel.unary_unary(
                '/powergate.user.v1.UserService/BuildInfo',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.BuildInfoRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.BuildInfoResponse.FromString,
                )
        self.UserIdentifier = channel.unary_unary(
                '/powergate.user.v1.UserService/UserIdentifier',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.UserIdentifierRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.UserIdentifierResponse.FromString,
                )
        self.DefaultStorageConfig = channel.unary_unary(
                '/powergate.user.v1.UserService/DefaultStorageConfig',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.DefaultStorageConfigRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.DefaultStorageConfigResponse.FromString,
                )
        self.SetDefaultStorageConfig = channel.unary_unary(
                '/powergate.user.v1.UserService/SetDefaultStorageConfig',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.SetDefaultStorageConfigRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.SetDefaultStorageConfigResponse.FromString,
                )
        self.ApplyStorageConfig = channel.unary_unary(
                '/powergate.user.v1.UserService/ApplyStorageConfig',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ApplyStorageConfigRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ApplyStorageConfigResponse.FromString,
                )
        self.Remove = channel.unary_unary(
                '/powergate.user.v1.UserService/Remove',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.RemoveRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.RemoveResponse.FromString,
                )
        self.Stage = channel.stream_unary(
                '/powergate.user.v1.UserService/Stage',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StageRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StageResponse.FromString,
                )
        self.StageCid = channel.unary_unary(
                '/powergate.user.v1.UserService/StageCid',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StageCidRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StageCidResponse.FromString,
                )
        self.ReplaceData = channel.unary_unary(
                '/powergate.user.v1.UserService/ReplaceData',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ReplaceDataRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ReplaceDataResponse.FromString,
                )
        self.Get = channel.unary_stream(
                '/powergate.user.v1.UserService/Get',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.GetRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.GetResponse.FromString,
                )
        self.WatchLogs = channel.unary_stream(
                '/powergate.user.v1.UserService/WatchLogs',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchLogsRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchLogsResponse.FromString,
                )
        self.CidSummary = channel.unary_unary(
                '/powergate.user.v1.UserService/CidSummary',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.CidSummaryRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.CidSummaryResponse.FromString,
                )
        self.CidInfo = channel.unary_unary(
                '/powergate.user.v1.UserService/CidInfo',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.CidInfoRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.CidInfoResponse.FromString,
                )
        self.Balance = channel.unary_unary(
                '/powergate.user.v1.UserService/Balance',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.BalanceRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.BalanceResponse.FromString,
                )
        self.NewAddress = channel.unary_unary(
                '/powergate.user.v1.UserService/NewAddress',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.NewAddressRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.NewAddressResponse.FromString,
                )
        self.Addresses = channel.unary_unary(
                '/powergate.user.v1.UserService/Addresses',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.AddressesRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.AddressesResponse.FromString,
                )
        self.SendFil = channel.unary_unary(
                '/powergate.user.v1.UserService/SendFil',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.SendFilRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.SendFilResponse.FromString,
                )
        self.SignMessage = channel.unary_unary(
                '/powergate.user.v1.UserService/SignMessage',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.SignMessageRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.SignMessageResponse.FromString,
                )
        self.VerifyMessage = channel.unary_unary(
                '/powergate.user.v1.UserService/VerifyMessage',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.VerifyMessageRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.VerifyMessageResponse.FromString,
                )
        self.StorageInfo = channel.unary_unary(
                '/powergate.user.v1.UserService/StorageInfo',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageInfoRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageInfoResponse.FromString,
                )
        self.ListStorageInfo = channel.unary_unary(
                '/powergate.user.v1.UserService/ListStorageInfo',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageInfoRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageInfoResponse.FromString,
                )
        self.StorageJob = channel.unary_unary(
                '/powergate.user.v1.UserService/StorageJob',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobResponse.FromString,
                )
        self.StorageConfigForJob = channel.unary_unary(
                '/powergate.user.v1.UserService/StorageConfigForJob',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageConfigForJobRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageConfigForJobResponse.FromString,
                )
        self.ListStorageJobs = channel.unary_unary(
                '/powergate.user.v1.UserService/ListStorageJobs',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageJobsRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageJobsResponse.FromString,
                )
        self.StorageJobsSummary = channel.unary_unary(
                '/powergate.user.v1.UserService/StorageJobsSummary',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobsSummaryRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobsSummaryResponse.FromString,
                )
        self.WatchStorageJobs = channel.unary_stream(
                '/powergate.user.v1.UserService/WatchStorageJobs',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchStorageJobsRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchStorageJobsResponse.FromString,
                )
        self.CancelStorageJob = channel.unary_unary(
                '/powergate.user.v1.UserService/CancelStorageJob',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.CancelStorageJobRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.CancelStorageJobResponse.FromString,
                )
        self.StorageDealRecords = channel.unary_unary(
                '/powergate.user.v1.UserService/StorageDealRecords',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageDealRecordsRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageDealRecordsResponse.FromString,
                )
        self.RetrievalDealRecords = channel.unary_unary(
                '/powergate.user.v1.UserService/RetrievalDealRecords',
                request_serializer=powergate_dot_user_dot_v1_dot_user__pb2.RetrievalDealRecordsRequest.SerializeToString,
                response_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.RetrievalDealRecordsResponse.FromString,
                )


class UserServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BuildInfo(self, request, context):
        """Top level
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserIdentifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DefaultStorageConfig(self, request, context):
        """Storage config
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDefaultStorageConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApplyStorageConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Remove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stage(self, request_iterator, context):
        """Data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StageCid(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReplaceData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CidSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CidInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Balance(self, request, context):
        """Wallet
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NewAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Addresses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendFil(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageInfo(self, request, context):
        """Storage Info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListStorageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageJob(self, request, context):
        """Storage Jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageConfigForJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListStorageJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageJobsSummary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchStorageJobs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelStorageJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StorageDealRecords(self, request, context):
        """Deals
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrievalDealRecords(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BuildInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildInfo,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.BuildInfoRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.BuildInfoResponse.SerializeToString,
            ),
            'UserIdentifier': grpc.unary_unary_rpc_method_handler(
                    servicer.UserIdentifier,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.UserIdentifierRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.UserIdentifierResponse.SerializeToString,
            ),
            'DefaultStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.DefaultStorageConfig,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.DefaultStorageConfigRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.DefaultStorageConfigResponse.SerializeToString,
            ),
            'SetDefaultStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDefaultStorageConfig,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.SetDefaultStorageConfigRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.SetDefaultStorageConfigResponse.SerializeToString,
            ),
            'ApplyStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.ApplyStorageConfig,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ApplyStorageConfigRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ApplyStorageConfigResponse.SerializeToString,
            ),
            'Remove': grpc.unary_unary_rpc_method_handler(
                    servicer.Remove,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.RemoveRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.RemoveResponse.SerializeToString,
            ),
            'Stage': grpc.stream_unary_rpc_method_handler(
                    servicer.Stage,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StageRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StageResponse.SerializeToString,
            ),
            'StageCid': grpc.unary_unary_rpc_method_handler(
                    servicer.StageCid,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StageCidRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StageCidResponse.SerializeToString,
            ),
            'ReplaceData': grpc.unary_unary_rpc_method_handler(
                    servicer.ReplaceData,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ReplaceDataRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ReplaceDataResponse.SerializeToString,
            ),
            'Get': grpc.unary_stream_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.GetRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.GetResponse.SerializeToString,
            ),
            'WatchLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchLogs,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchLogsRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchLogsResponse.SerializeToString,
            ),
            'CidSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.CidSummary,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.CidSummaryRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.CidSummaryResponse.SerializeToString,
            ),
            'CidInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.CidInfo,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.CidInfoRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.CidInfoResponse.SerializeToString,
            ),
            'Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.Balance,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.BalanceRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.BalanceResponse.SerializeToString,
            ),
            'NewAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.NewAddress,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.NewAddressRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.NewAddressResponse.SerializeToString,
            ),
            'Addresses': grpc.unary_unary_rpc_method_handler(
                    servicer.Addresses,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.AddressesRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.AddressesResponse.SerializeToString,
            ),
            'SendFil': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFil,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.SendFilRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.SendFilResponse.SerializeToString,
            ),
            'SignMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.SignMessage,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.SignMessageRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.SignMessageResponse.SerializeToString,
            ),
            'VerifyMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyMessage,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.VerifyMessageRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.VerifyMessageResponse.SerializeToString,
            ),
            'StorageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageInfo,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageInfoRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageInfoResponse.SerializeToString,
            ),
            'ListStorageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStorageInfo,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageInfoRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageInfoResponse.SerializeToString,
            ),
            'StorageJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageJob,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobResponse.SerializeToString,
            ),
            'StorageConfigForJob': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageConfigForJob,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageConfigForJobRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageConfigForJobResponse.SerializeToString,
            ),
            'ListStorageJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListStorageJobs,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageJobsRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.ListStorageJobsResponse.SerializeToString,
            ),
            'StorageJobsSummary': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageJobsSummary,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobsSummaryRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageJobsSummaryResponse.SerializeToString,
            ),
            'WatchStorageJobs': grpc.unary_stream_rpc_method_handler(
                    servicer.WatchStorageJobs,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchStorageJobsRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.WatchStorageJobsResponse.SerializeToString,
            ),
            'CancelStorageJob': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelStorageJob,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.CancelStorageJobRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.CancelStorageJobResponse.SerializeToString,
            ),
            'StorageDealRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.StorageDealRecords,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageDealRecordsRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.StorageDealRecordsResponse.SerializeToString,
            ),
            'RetrievalDealRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrievalDealRecords,
                    request_deserializer=powergate_dot_user_dot_v1_dot_user__pb2.RetrievalDealRecordsRequest.FromString,
                    response_serializer=powergate_dot_user_dot_v1_dot_user__pb2.RetrievalDealRecordsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'powergate.user.v1.UserService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BuildInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/BuildInfo',
            powergate_dot_user_dot_v1_dot_user__pb2.BuildInfoRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.BuildInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserIdentifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/UserIdentifier',
            powergate_dot_user_dot_v1_dot_user__pb2.UserIdentifierRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.UserIdentifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DefaultStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/DefaultStorageConfig',
            powergate_dot_user_dot_v1_dot_user__pb2.DefaultStorageConfigRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.DefaultStorageConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDefaultStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/SetDefaultStorageConfig',
            powergate_dot_user_dot_v1_dot_user__pb2.SetDefaultStorageConfigRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.SetDefaultStorageConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApplyStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/ApplyStorageConfig',
            powergate_dot_user_dot_v1_dot_user__pb2.ApplyStorageConfigRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.ApplyStorageConfigResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Remove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/Remove',
            powergate_dot_user_dot_v1_dot_user__pb2.RemoveRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.RemoveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stage(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/powergate.user.v1.UserService/Stage',
            powergate_dot_user_dot_v1_dot_user__pb2.StageRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.StageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StageCid(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/StageCid',
            powergate_dot_user_dot_v1_dot_user__pb2.StageCidRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.StageCidResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReplaceData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/ReplaceData',
            powergate_dot_user_dot_v1_dot_user__pb2.ReplaceDataRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.ReplaceDataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/powergate.user.v1.UserService/Get',
            powergate_dot_user_dot_v1_dot_user__pb2.GetRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.GetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/powergate.user.v1.UserService/WatchLogs',
            powergate_dot_user_dot_v1_dot_user__pb2.WatchLogsRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.WatchLogsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CidSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/CidSummary',
            powergate_dot_user_dot_v1_dot_user__pb2.CidSummaryRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.CidSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CidInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/CidInfo',
            powergate_dot_user_dot_v1_dot_user__pb2.CidInfoRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.CidInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/Balance',
            powergate_dot_user_dot_v1_dot_user__pb2.BalanceRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.BalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NewAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/NewAddress',
            powergate_dot_user_dot_v1_dot_user__pb2.NewAddressRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.NewAddressResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Addresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/Addresses',
            powergate_dot_user_dot_v1_dot_user__pb2.AddressesRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.AddressesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendFil(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/SendFil',
            powergate_dot_user_dot_v1_dot_user__pb2.SendFilRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.SendFilResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/SignMessage',
            powergate_dot_user_dot_v1_dot_user__pb2.SignMessageRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.SignMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/VerifyMessage',
            powergate_dot_user_dot_v1_dot_user__pb2.VerifyMessageRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.VerifyMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/StorageInfo',
            powergate_dot_user_dot_v1_dot_user__pb2.StorageInfoRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.StorageInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListStorageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/ListStorageInfo',
            powergate_dot_user_dot_v1_dot_user__pb2.ListStorageInfoRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.ListStorageInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/StorageJob',
            powergate_dot_user_dot_v1_dot_user__pb2.StorageJobRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.StorageJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageConfigForJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/StorageConfigForJob',
            powergate_dot_user_dot_v1_dot_user__pb2.StorageConfigForJobRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.StorageConfigForJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListStorageJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/ListStorageJobs',
            powergate_dot_user_dot_v1_dot_user__pb2.ListStorageJobsRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.ListStorageJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageJobsSummary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/StorageJobsSummary',
            powergate_dot_user_dot_v1_dot_user__pb2.StorageJobsSummaryRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.StorageJobsSummaryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WatchStorageJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/powergate.user.v1.UserService/WatchStorageJobs',
            powergate_dot_user_dot_v1_dot_user__pb2.WatchStorageJobsRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.WatchStorageJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelStorageJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/CancelStorageJob',
            powergate_dot_user_dot_v1_dot_user__pb2.CancelStorageJobRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.CancelStorageJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StorageDealRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/StorageDealRecords',
            powergate_dot_user_dot_v1_dot_user__pb2.StorageDealRecordsRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.StorageDealRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrievalDealRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/powergate.user.v1.UserService/RetrievalDealRecords',
            powergate_dot_user_dot_v1_dot_user__pb2.RetrievalDealRecordsRequest.SerializeToString,
            powergate_dot_user_dot_v1_dot_user__pb2.RetrievalDealRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import setuptools

setuptools.setup(
    name="grpc_powergate_client",
    version="2.6.0",
    author="Textile",
    author_email="contact@textile.io",
    url="https://github.com/textileio/powergate",
    packages=setuptools.find_packages(where="src"),
    package_dir={'': 'src'},
    install_requires=[
      'protobuf',
      'grpcio',
    ],
)
